#include <iostream>
#include <vector>
#include <cmath>
#include <set>
#include <deque>
#include <queue>
#include <algorithm>
#include <map>
#include <string>
#define int long long
using namespace std;

int gcd(int a, int b) {
    if (b == 0) return a;
    return gcd(b, a % b);
}

double binpow(double a, int n) { // a ^ n % m
    if (n == 0) return 1;
    if (n % 2 == 0) {
        double x = binpow(a, n / 2);
        return x * x;
    }
    else return a * binpow(a, n - 1);
}

int phi(int n) {
    int res = n;
    for (int p = 2; p * p <= n; ++p) {
        if (n % p == 0)
            res -= res / p;
        while (n % p == 0)
            n /= p;
    }
    if (n > 1)
        res -= res / n;
    return res;
}

vector<int> factorization(int n) {
    vector<int> p;
    for (int d = 2; d * 1ll * d <= n; ++d) {
        if (n % d == 0) p.push_back(d);
        while (n % d == 0) {
            n /= d;
        }
    }
    if (n > 1) {
        p.push_back(n);
    }
    return p;
}

struct Tree {
  int n;
  vector<int> t;

  void build(vector<int>& A) {
    n = 1; //     
    while (n < A.size()) n *= 2;
    t.resize(n * 2);
    for (int i = n; i < (n + A.size()); ++i) {
      t[i] = A[i - n];
    }
    for (int i = (n - 1); i <= 1; --i) {
      t[i] = t[i * 2] + t[i * 2 + 1];
    }
  }

  void set(int ind, int value) {
    ind += n;
    t[ind] = value;
    ind /= 2;
    while (ind >= 1) {
      t[ind] = t[ind * 2] + t[ind * 2 + 1];
      ind /= 2;
    }
  }

  int getsum(int l, int r) {
    l += n;
    r += n;
    int sum = 0;
    for (; l <= r; l /= 2, r /= 2) {
      if (l % 2 == 1) {
        sum += t[l];
        l++;
      }
      if (r % 2 == 0) {
        sum += t[r];
        r--;
     }
    }

    return sum;
  }
};

int solve1(int a, int b) {

    int sqrta = sqrt(a), sqrtb = sqrt(b);
    int cnt = 0;
    for (int i = a; i <= b; ++i) {
        int cur = i;
        int nwcur = 0;
        if (cur % 10 == 0) continue;
        while (cur) {
            nwcur *= 10;
            nwcur += (cur % 10);
            cur /= 10;
        }
        int sqrtn = sqrt(nwcur), sqrti = sqrt(i);
        if (sqrtn * sqrtn == nwcur && sqrti * sqrti == i) {
            ++cnt;
        }
    }
    return cnt;
}

int solve2(int a, int b) {



    int sqrta = ceil(sqrt(a)), sqrtb = sqrt(b);
    int cnt = 0;
    for (int i = sqrta; i <= sqrtb; ++i) {
        int cur = i * i;
        int nwcur = 0;
        if (cur % 10 == 0) continue;
        while (cur) {
            nwcur *= 10;
            nwcur += (cur % 10);
            cur /= 10;
        }
        int sqrtn = sqrt(nwcur), sqrti = sqrt(i);
        if (sqrtn * sqrtn == nwcur) {
            ++cnt;
        }
    }
    return cnt;
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);


    /*for (int i = 1; i < 1000; ++i) {
        for (int j = i + 1; j < 1000; ++j) {
            if (solve1(i, j) != solve2(i, j)) {
                cout << "WA: " << i << " " << j << endl;
                cout << solve1(i, j) << " " << solve2(i, j);
                return 0;
            }
        }
    }*/
    int a, b; cin >> a >> b;
    cout << solve2(a, b);
}
