#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <vector>

typedef long long INT;

template<typename type>
void aux_sort( type *arr, INT len, type *aux_arr )
{
  if (len <= 1)
    return;

  INT mid = len / 2;
  aux_sort(arr, mid, aux_arr);
  aux_sort(arr + mid, len - mid, aux_arr + mid);

  INT i1 = 0, i2 = mid, j = 0;
  while (i1 < mid && i2 < len)
  {
    if (arr[i1] < arr[i2])
      aux_arr[j++] = arr[i1++];
    else
      aux_arr[j++] = arr[i2++];
  }
  while (i1 < mid)
    aux_arr[j++] = arr[i1++];
  while (i2 < len)
    aux_arr[j++] = arr[i2++];

  memcpy(arr, aux_arr, sizeof (type) * len);
} /* End of 'aux_sort' function */

template<typename type>
inline void sort( type *arr, INT len )
{
  std::vector<type> aux_arr {};
  aux_arr.resize(len);

  aux_sort(arr, len, aux_arr.data());
} /* End of 'sort' function */

int main( void )
{
  INT n {}, a {}, b {};

  scanf("%lli %lli %lli", &n, &a, &b);

  struct data
  {
  public:
    INT TScore {}, PScore {};
    INT Diff {};
    INT Origin {};
  };

  struct data_ptr
  {
  public:
    data *ptr {};

    bool operator<( const data_ptr &val )
    {
      return abs(ptr->Diff) < abs(val.ptr->Diff);
    }
  };

  std::vector<data> Exams {};
  Exams.resize(n);
  for (INT i = 0; i < n; i++)
    scanf("%lli", &Exams[i].TScore);
  for (INT i = 0; i < n; i++)
    scanf("%lli", &Exams[i].PScore);

  std::vector<data_ptr> ExamsPtrs {};
  ExamsPtrs.resize(n);

  for (INT i = 0; i < n; i++)
  {
    Exams[i].Diff = Exams[i].TScore - Exams[i].PScore;
    Exams[i].Origin = i;
    ExamsPtrs[i].ptr = Exams.data() + i;
  }

  sort(ExamsPtrs.data(), n);

  INT free = n - a - b, i = n - 1;

  std::vector<bool> Res {};
  Res.resize(n);

  while (free > 0)
  {
    if (ExamsPtrs[i].ptr->Diff > 0)
    {
      if (a > 0)
        a--;
      else
        free--;

      Res[ExamsPtrs[i--].ptr->Origin] = false;
    }
    else
    {
      if (b > 0)
        b--;
      else
        free--;

      Res[ExamsPtrs[i--].ptr->Origin] = true;
    }
  }

  while (a > 0 && b > 0)
  {
    if (ExamsPtrs[i].ptr->Diff > 0)
    {
      Res[ExamsPtrs[i--].ptr->Origin] = false;
      a--;
    }
    else
    {
      Res[ExamsPtrs[i--].ptr->Origin] = true;
      b--;
    }
  }

  while (a > 0)
  {
    Res[ExamsPtrs[i--].ptr->Origin] = false;
    a--;
  }

  while (b > 0)
  {
    Res[ExamsPtrs[i--].ptr->Origin] = true;
    b--;
  }

  INT sum = 0;

  for (INT i = 0; i < n; i++)
    sum += Res[i] ? Exams[i].PScore : Exams[i].TScore;

  printf("%lli\n", sum);

  for (INT i = 0; i < n - 1; i++)
    printf(Res[i] ? "P " : "T ");
  printf(Res[n - 1] ? "P\n" : "T\n");

  return 0;
} /* End of 'main' function */
